Structura
=====================================

.. image:: https://github.com/sekomer/structura/workflows/Tests/badge.svg
   :alt: Structura build status on GitHub Actions
   :target: https://github.com/sekomer/structura/actions


|

.. contents::


.. highlight:: bash

Installation
------------
From The Python Package Index

``pip install structura``
    
    
General Information
-------------------
- Source code: https://github.com/sekomer/structura
- Documentation: [ TODO ]

Contributing
------------
All contributions, suggestions, and optimization ideas are welcome!

Using Structura
------------
[ TODO ]

Build Instructions
------------------
To build `structura` from source, you should clone the repo and run the following command

``sudo python3 setup.py install``

What's New
----------
- 0.1.2
    - RingBuffer
- 0.2.0
    - Stack
    - LinkedList


What's Coming
-------------
Queues, Hash Tables, Trees, iterables.

Proposals for enhancement
-------------------------
You can create an issue or mail me at a.serkanaksoz@gmail.com
